@@ -46,11 +46,26 @@ class HierarchySerializer(serializers.ModelSerializer):
     """
     objectid = ReestrObjectsSerializer()
     parentobjid = ReestrObjectsSerializer()
+    name_with_parents = serializers.SerializerMethodField()
 
     class Meta:
         model = Hierarchy
         fields = '__all__'
 
+    def get_name_with_parents(self, obj):
+        result_parts = []
+        for item in obj.get_ancestors(include_self=True):
+            try:
+                addr_obj = AddrObj.objects.get(objectid=item.objectid_id)
+            except:
+                print('error')
+            else:
+                result_parts.append(f'{addr_obj.name} {addr_obj.typename}')
+
+        result = ', '.join(result_parts)
+
+        return result
+
 
 class MunHierarchySerializer(HierarchySerializer):
     """
